==> libdombey-1.9.tar.gz: libdombey-1.9/test.c <==
/*
 * Copyright (c) 2010, James Bailie.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *     * The name of James Bailie may not be used to endorse or promote
 * products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>

#include "dombey.h"

char **env, **params, **cookies;

void scgi_init_func()
{
   scgi_set_name( "test" );

   env = scgi_get_envs();
   params = scgi_get_params();
   cookies = scgi_get_cookies();
}

void scgi_child_init_func()
{
}

void send_headers ()
{
   puts( "Content-Type: text/html; charset=utf-8\n\n"

      "<!DOCTYPE html>\n"
      "<html>\n"
      "<head>\n"

      "<title>LibDombey Test Program</title>\n"
      "\n"

      "<meta name=\"description\" content=\"The LibDombey 'hello world!'\" />\n"
      "<meta name=\"language\" content=\"EN\" />\n"
      "<meta name=\"keywords\" content=\"SCGI,CGI,application server\" />\n"

      "\n"

      "<style type=\"text/css\">\n"
      "   BODY { margin: 0;\n"
      "          padding: 1%;\n"
      "          color: #404040;\n"
      "          background: #ffffff;\n"
      "   }\n"
      "   TD { padding-left: 1% }\n"
      "</style>\n"

      "\n"

      "</head>\n"
      "<body>\n"
   );
}

void scgi_request_handler()
{
   char **ptr;

   send_headers();

   printf( "<h1>LibDombey Test Program</h1>\n\n"
           "<p>value of scgi_config_file option: %s</p>\n"
           "<h2>SCGI Environment:</h2>\n\n"
           "<table>",
           ( scgi_config_file == NULL ? "(not set)" : scgi_config_file ));

   for( ptr = env; *ptr != NULL; ptr += 2 )
      printf( "<tr><td>%s:</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ));

   puts( "</table>\n\n<h2>SCGI Parameters:</h2>\n\n<table>" );

   for( ptr = params; *ptr != NULL; ptr += 2 )
      printf( "<tr><td>%s:</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ));

   puts( "</table>\n\n<h2>Cookies:</h2>\n\n<table>" );

   for( ptr = cookies; *ptr != NULL; ptr += 2 )
      printf( "<tr><td>%s:</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ));


   puts( "</table>\n</body>\n</html>" );
}

==> libdombey-2.1.tar.gz: libdombey-2.1/test.c <==
/*
 * Copyright (c) 2010, James Bailie.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *     * The name of James Bailie may not be used to endorse or promote
 * products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>

#include "dombey.h"

char **env, **params, **files, **cookies;

void scgi_init_func()
{
   scgi_set_name( "test" );

   env = scgi_get_envs();
   params = scgi_get_params();
   files = scgi_get_files();
   cookies = scgi_get_cookies();
}

void scgi_child_init_func()
{
}

void send_headers ()
{
   puts( "Content-Type: text/html; charset=utf-8\n\n"

      "<!DOCTYPE html>\n"
      "<html>\n"
      "<head>\n"

      "<title>LibDombey Test Program</title>\n"
      "\n"

      "<meta name=\"description\" content=\"The LibDombey 'hello world!'\" />\n"
      "<meta name=\"language\" content=\"EN\" />\n"
      "<meta name=\"keywords\" content=\"SCGI,CGI,application server\" />\n"

      "\n"

      "<style type=\"text/css\">\n"
      "   BODY { margin: 0;\n"
      "          padding: 1%;\n"
      "          color: #404040;\n"
      "          background: #ffffff;\n"
      "   }\n"
      "   TD { padding-left: 1% }\n"
      "</style>\n"

      "\n"

      "</head>\n"
      "<body>\n"
   );
}

void scgi_request_handler()
{
   char **ptr;

   send_headers();

   printf( "<h1>LibDombey Test Program</h1>\n\n"
           "<p>value of scgi_config_file option: %s</p>\n"
           "<h2>SCGI Environment:</h2>\n\n"
           "<table>",
           ( scgi_config_file == NULL ? "(not set)" : scgi_config_file ));

   for( ptr = env; *ptr != NULL; ptr += 2 )
      printf( "<tr><td>%s:</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ));

   puts( "</table>\n\n<h2>SCGI Parameters:</h2>\n\n<table>" );

   for( ptr = params; *ptr != NULL; ptr += 2 )
      printf( "<tr><td>%s:</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ));

   puts( "</table>\n\n<h2>Uploaded Files:</h2>\n\n<table>" );

   for( ptr = files; *ptr != NULL; ptr += 3 )
      printf( "<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ), *( ptr + 2 ));

   puts( "</table>\n\n<h2>Cookies:</h2>\n\n<table>" );

   for( ptr = cookies; *ptr != NULL; ptr += 2 )
      printf( "<tr><td>%s:</td><td>%s</td></tr>\n", *ptr, *( ptr + 1 ));

   puts( "</table>\n</body>\n</html>" );
}
